# -*- coding: utf-8 -*-
# Copyright 2020 The PsiZ Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ============================================================================
"""Module of Keras regularizers."""

from psiz.keras.regularizers.attention_entropy import AttentionEntropy
from psiz.keras.regularizers.squeeze import Squeeze
from psiz.keras.regularizers.stimulus_normed_l1 import StimulusNormedL1

__all__ = [
    "AttentionEntropy",
    "Squeeze",
    "StimulusNormedL1",
]
